"""
    Registry User Dashboard constants
"""
# Templates
DASHBOARD_HOME_TEMPLATE = "core_dashboard_registry_app/home.html"
DASHBOARD_FORMS_TEMPLATE_TABLE = (
    "core_dashboard_registry_app/list/my_dashboard_my_forms_table.html"
)
DASHBOARD_FORMS_TEMPLATE_TABLE_PAGINATION = (
    "core_dashboard_registry_app/list/my_dashboard_my_forms_table_pagination.html"
)
# JS
JS_PUBLISH_RESOURCE = "core_dashboard_registry_app/user/js/list/publish.js"
JS_RECORD_REGISTRY = "core_dashboard_registry_app/user/js/record_registry.js"

# CSS
CSS_SELECTION = "core_main_registry_app/user/css/resource_banner/selection.css"

# PATH
PATH_ROLE = "dict_content.Resource.role.@xsi:type"



"""
    Url router for the user dashboard
"""
from django.contrib.auth.decorators import login_required
from django.urls import re_path
from django.urls import reverse_lazy

from core_dashboard_common_app import constants as dashboard_constants
from core_dashboard_common_app.views.common import ajax, views as common_views
from core_dashboard_common_app.views.common.views import (
    UserDashboardPasswordChangeFormView,
)
from core_dashboard_registry_app.views.common import ajax as registry_common_ajax
from core_dashboard_registry_app.views.common import views as registry_common_views
from core_dashboard_registry_app.views.common.ajax import EditDataView

urlpatterns = [
    # Common
    re_path(r"^$", registry_common_views.home, name="core_dashboard_home"),
    re_path(r"^my-profile$", common_views.my_profile, name="core_dashboard_profile"),
    re_path(
        r"^my-profile/edit$",
        common_views.my_profile_edit,
        name="core_dashboard_profile_edit",
    ),
    re_path(
        r"^my-profile/change-password",
        UserDashboardPasswordChangeFormView.as_view(
            template_name="core_dashboard_common_app/my_profile_change_password.html",
            success_url="/",
        ),
        name="core_dashboard_profile_change_password",
    ),
    re_path(
        r"^delete-document", ajax.delete_document, name="core_dashboard_delete_document"
    ),
    re_path(
        r"^change-owner",
        ajax.change_owner_document,
        name="core_dashboard_change_owner_document",
    ),
    re_path(r"^edit-record", ajax.edit_record, name="core_dashboard_edit_record"),
    # User
    re_path(
        r"^records$",
        login_required(
            registry_common_views.DashboardRegistryRecords.as_view(
                document=dashboard_constants.FUNCTIONAL_OBJECT_ENUM.RECORD.value,
                data_template="core_dashboard_registry_app/list/my_dashboard_my_records_table_pagination.html",
                allow_change_workspace_if_public=False,
            ),
            login_url=reverse_lazy("core_main_app_login"),
        ),
        name="core_dashboard_records",
    ),
    re_path(
        r"^switch-status-record",
        registry_common_ajax.switch_data_status,
        name="core_dashboard_switch_status_record",
    ),
    re_path(
        r"^forms$",
        login_required(
            registry_common_views.DashboardRegistryForms.as_view(
                document=dashboard_constants.FUNCTIONAL_OBJECT_ENUM.FORM.value
            ),
            login_url=reverse_lazy("core_main_app_login"),
        ),
        name="core_dashboard_forms",
    ),
    re_path(
        r"^workspaces$",
        login_required(
            common_views.DashboardWorkspaces.as_view(),
            login_url=reverse_lazy("core_main_app_login"),
        ),
        name="core_dashboard_workspaces",
    ),
    re_path(
        r"^workspace-list-records/(?P<workspace_id>\w+)$",
        login_required(
            registry_common_views.DashboardRegistryWorkspaceRecords.as_view(
                data_template="core_dashboard_registry_app/list/my_dashboard_my_records_table_pagination.html"
            ),
            login_url=reverse_lazy("core_main_app_login"),
        ),
        name="core_dashboard_workspace_list",
    ),
    re_path(
        r"^publish-resource",
        registry_common_ajax.publish,
        name="core_dashboard_publish_resource_registry",
    ),
    re_path(
        r"^dashboard-data/(?P<pk>[\w-]+)/edit/$",
        EditDataView.as_view(),
        name="core_dashboard_app_edit_data",
    ),
]



""" Mongo query builder tools
"""
from core_dashboard_registry_app.constants import PATH_ROLE


def create_query_dashboard_resources(request, role_name_list, administration):
    """ Create a query for the dashboard.

    Args:
        request:
        role_name_list:
        administration:

    Returns:
    """
    query = {}

    # if at least one role
    if len(role_name_list) > 0:
        query["$or"] = [{PATH_ROLE: role} for role in role_name_list]

    # user
    if not administration:
        query["user_id"] = str(request.user.id)

    return query



"""
    User Dashboard menu
"""
from django.urls import reverse
from menu import Menu, MenuItem

import core_dashboard_registry_app.settings as settings
from core_dashboard_common_app.constants import FUNCTIONAL_OBJECT_ENUM

Menu.add_item(
    "dashboard",
    MenuItem(
        "{0}s".format(FUNCTIONAL_OBJECT_ENUM.RECORD.value.title()),
        reverse("core_dashboard_records"),
    ),
)

Menu.add_item(
    "dashboard",
    MenuItem(
        "{0}s".format(FUNCTIONAL_OBJECT_ENUM.WORKSPACE.value.title()),
        reverse("core_dashboard_workspaces"),
    ),
)

sharing_children = (
    MenuItem(
        "All {0}s".format(FUNCTIONAL_OBJECT_ENUM.RECORD.value.title()),
        reverse("admin:core_dashboard_records"),
        icon="list",
    ),
    MenuItem(
        "All {0}s".format(FUNCTIONAL_OBJECT_ENUM.WORKSPACE.value.title()),
        reverse("admin:core_dashboard_workspaces"),
        icon="list",
    ),
)

if "core_curate_app" in settings.INSTALLED_APPS:
    Menu.add_item(
        "dashboard",
        MenuItem(
            "{0}s".format(FUNCTIONAL_OBJECT_ENUM.FORM.value.title()),
            reverse("core_dashboard_forms"),
        ),
    )
    sharing_children += (
        MenuItem(
            "All {0}s".format(FUNCTIONAL_OBJECT_ENUM.FORM.value.title()),
            reverse("admin:core_dashboard_forms"),
            icon="list",
        ),
    )

Menu.add_item("user", MenuItem("My Profile", reverse("core_dashboard_profile")))

Menu.add_item("admin", MenuItem("DASHBOARD", None, children=sharing_children))

Menu.add_item(
    "main",
    MenuItem(
        "Dashboard",
        reverse("core_dashboard_home"),
        check=lambda request: request.user.is_authenticated,
    ),
)
